# VRCpy

API wrapper for the [VRChat API](https://vrchatapi.github.io), supporting both synchronous and asynchronous structures     

See the [examples](https://github.com/VRChatAPI/VRChatPython/tree/master/examples) folder for examples on how to use the wrapper

## Installation

`pip install vrcpy`

Or if you are using async and want to improve speed

`pip install vrcpy[aquick]`
